#
# spec file for package megaglest
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           megaglest
Version:        3.13.0
Release:        8.5
Summary:        Customizable 3D real-time strategy game
License:        GPL-3.0-or-later
Group:          Amusements/Games/Strategy/Real Time
URL:            https://megaglest.org/
Source:         https://github.com/MegaGlest/megaglest-source/releases/download/%{version}/%{name}-source-%{version}.tar.xz
# for grepping a constant build time to recieve reproducible builds
Source99:       %{name}.changes
# PATCH-FIX-UPSTREAM wxwidgets3.patch - https://github.com/MegaGlest/megaglest-source/pull/163
Patch0:         wxwidgets3.patch
Patch1:         wxwidgets3_1.patch
BuildRequires:  ImageMagick
BuildRequires:  boost-jam
BuildRequires:  cmake
BuildRequires:  freealut-devel
BuildRequires:  freeglut-devel
BuildRequires:  fribidi-devel
BuildRequires:  ftgl-devel
BuildRequires:  gcc-c++
BuildRequires:  glew-devel
BuildRequires:  hicolor-icon-theme
BuildRequires:  krb5-devel
BuildRequires:  libcares-devel
BuildRequires:  libcurl-devel >= 7.21
BuildRequires:  libdrm-devel
BuildRequires:  libidn-devel
BuildRequires:  libircclient-devel
BuildRequires:  libjpeg-devel
BuildRequires:  libminiupnpc-devel
BuildRequires:  libopenssl-devel
BuildRequires:  libssh2-devel
BuildRequires:  libvorbis-devel
BuildRequires:  libxerces-c-devel
BuildRequires:  lua51-devel
BuildRequires:  openal-soft-devel
BuildRequires:  openldap2-devel
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  wxWidgets-devel
BuildRequires:  xorg-x11-Mesa-devel
BuildRequires:  xorg-x11-libX11-devel
BuildRequires:  pkgconfig(libpng16)
BuildRequires:  pkgconfig(libvlc)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(sdl2)
Requires:       freefont
Requires:       gnu-free-fonts
Requires:       linux-libertine-fonts
Requires:       megaglest-data >= %{version}
Requires:       p7zip-full

%description
MegaGlest takes place in a context that could be compared to that of
pre-Renaissance Europe with the twist that magic forces exist in the
environment and can be controlled.

A game takes place on a map of varying size, such as large plains and
fields, with terrain features like rivers, mountains, seas, or
cliffs. Players must establish settlements to gain resources, defend
against other players, and train units to explore the map and attack
enemies.

%prep
%autosetup -p1

%build
export CFLAGS="%{optflags} -fcommon"
%cmake \
  -DWANT_SVN_STAMP=OFF
# unforce link against libcurl.a
find . -name link.txt -exec sed -ie 's!%{_prefix}/lib/libcurl.a!-lcurl!g' {} \;
find . -name link.txt -exec sed -ie 's!%{_libdir}/libcurl.a!-lcurl!g' {} \;
%cmake_build

%install
%cmake_install
mkdir -p %{buildroot}%{_datadir}/%{name}/data
mkdir -p %{buildroot}%{_datadir}/icons/hicolor/{16x16,32x32,48x48}/apps

for image in megaglest g3dviewer editor; do
    convert "mk/shared/$image.ico[0]" -strip "%{buildroot}%{_datadir}/icons/hicolor/16x16/apps/megaglest_$image.png"
    convert "mk/shared/$image.ico[1]" -strip "%{buildroot}%{_datadir}/icons/hicolor/32x32/apps/megaglest_$image.png"
    convert "mk/shared/$image.ico[2]" -strip "%{buildroot}%{_datadir}/icons/hicolor/48x48/apps/megaglest_$image.png"
done
%suse_update_desktop_file -c megaglest        "MegaGlest"        "Real-time strategy game"  megaglest           megaglest_megaglest Game StrategyGame
%suse_update_desktop_file -c megaglest_editor "MegaGlest Editor" "Gamedata editor"          megaglest_editor    megaglest_editor    Game StrategyGame
%suse_update_desktop_file -c g3dviewer        g3dviewer          "Glest 3D Graphics Viewer" megaglest_g3dviewer megaglest_g3dviewer Graphics Viewer

%files
%{_bindir}/*
%{_datadir}/%{name}/
%{_datadir}/icons/hicolor/*/apps/megaglest_*.png
%{_datadir}/applications/*

%changelog
* Fri Feb 23 2024 pgajdos@suse.com
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN
* Sat Jun  4 2022 Jan Engelhardt <jengelh@inai.de>
- Remove BuildRequire on pkgconfig(glw), can't find any source file
  using it.
* Wed Apr 21 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Added wxwidgets3_1.patch to fix build with factory
* Tue Aug 25 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Fixes for %%_libexecdir changing to /usr/libexec (bsc#1174075)
* Wed Jun 17 2020 Martin Pluskal <mpluskal@suse.com>
- Fix building with gcc10
- Modernise spec file
* Fri Jun 29 2018 kstreitova@suse.com
- require p7zip-full for TW as 7z/7za binaries needed by megaglest
  were moved to this package (see bsc#899627 for more details
  about this change)
* Fri Apr  7 2017 jengelh@inai.de
- Expand description and trim redundant words from summary.
* Fri Mar 10 2017 rpm@fthiessen.de
- Fixed build on openSUSE Tumbleweed (wxWidgets 3.0):
  * Added wxwidgets3.patch to fix build with changed unicode
    handling in wxWidgets 3.
* Fri Mar 10 2017 joop.boonen@opensuse.org
- Build Version 3.13.0
  - important sounds like "attack alarm" are always played
  - display build/morph/upgrade time
  - new AI tag <ai-build-size> for units(buildings) which allows fake size for buildings while placing them
  - much better error handling and messages especially for modders and xml-related problems
  - fix unwanted double event for some keys ( like alt+enter )
  - map filter option for game setup on headless server
  - option to select/command multiple buildings of same type ( uniform-selection )
  - major cross platform OOS fix which especially showed up quite often when playing without fog of war
  - you must prove basic game knowledge before you can play online by winning a special scenario
  - less visible parts of black squares while rendering cliffs
  - possibility to let units spawn units on death
  - improved AI behavior per faction ( mostly magic )
- fix-new-miniupnpc.patch -- https://github.com/MegaGlest/megaglest-source/issues/121 has been resolved
- fix-not-declared.patch has been resolved
* Wed Jul 27 2016 rpm@fthiessen.de
- Added fix-not-declared.patch for gcc >= 6.
- Install .desktop files
- Some cleanup
* Fri May 13 2016 rpm@fthiessen.de
- Added fix-new-miniupnpc.patch for fixing build with miniupnpc
  API > 16 (e.g. on Factory / Tumbleweed), see also:
  https://github.com/MegaGlest/megaglest-source/issues/121
* Fri Feb 26 2016 ecsos@opensuse.org
- fix build error
- add BuildRequires fribidi, vlc, freealut
* Wed Feb  3 2016 joop.boonen@opensuse.org
- Update to version 3.12.0
  * MegaGlest uses SDL2 now
  * glowing meshes. ( models can glow like particles do )
  * console message for finished upgrades
  * new parameter to set servers titles
  * 5 new maps
  * improved network performance
  * better stability in the lobby
* Tue Nov 24 2015 rpm@fthiessen.de
- Fixed dependencies so it builds for openSUSE again.
- Some cleanup
* Mon May 11 2015 dap.darkness@gmail.com
- Update to version 3.11.1
  * no more false clicks when commanding via mini map;
  * map editor has a more useful and powerful map height
    randomizer;
  * map editor saves all maps with .mgm ending by default.
  * fixed map editor (several linux distributions had trouble);
  * for missing tilesets and techs optional download from mod
    center instead of server (bugfix);
  * healthbar default set to "if needed";
  * nicer tilesets as defaults;
  * improved camera startposition on game start (main building in
    center);
  * attackBoosts: Ep + Hp regeneration is shown in description.
- Added megaglest-3.11.1_cmake3.2-x11.patch vs.
  https://github.com/MegaGlest/megaglest-source/issues/65
* Tue Jan 27 2015 joop.boonen@opensuse.org
- Update to version 3.11.0
  * healthbars with a lot of options
  * multi shot / multi-projectiles with different timings,sounds and particle systems
  * several camera shake effects
  * new tileset "pine rock"
  * some new maps
  * improve switching settings when connected to a headless server
  * support for team unit sharing
  * team resource sharing
  * tags feature
  * Attack boosts fixed in many ways
  * Attack boosts and upgrades now support upgrading attack speed
  * timed particles and mesh bound particles really work now.
  * unit height independend particle positioning ( flat-particle-positions )
  * CPU players multiplier are displayed in debug view
  * You can have non commandable units
  * Units spawned by an attack skill can get an attack command
  * Unit and Splash particles can be speeded up ( accelerated )
  * Looting https://github.com/MegaGlest/megaglest-source/pull/17
  * HP and EP starting values
  * <target-height> <burn-height> can be given https://docs.megaglest.org/XML/Unit#target-height
  * +several bugfixes
* Fri Feb 28 2014 joop.boonen@opensuse.org
- Update to version 3.9.1
  * Includes many bug fixes reported in the forums since 3.9.0.
  * Backward compatible with 3.9.0.
  * Moved the project from sourceforge.net to github.com and from subversion to git.
  * Better handling of lagging clients in network games.
  * Fixed cmake scripts to correctly detect dependencies that were previously partially working on some distros and improved build support for Mac OS X.
  * Added numerous new LUA functions as documented at wiki.megaglest.org.
  * Code quality improvements as reported by cppcheck and coverity (and clang).
  * Better color picking algorithm thanks to willvarfar makes color picking very stable.
  * Render order improved to allow more transparency effects.
  * Adjustable camera scroll speed.
  * Particle systems can be bound to meshes of models.
* Sat Nov 23 2013 mailaender@opensuse.org
- https://en.opensuse.org/SourceUrls
- Update to version 3.9.0.4
  * Hopefully solved the last out of sync problems for cross platform games.
  * Animated tileset object (like trees moving in the wind) support.
  * New tileset texturing possibilities
  * New tilesets birchforest, desert4 and updated mediterran using animated objects and new texture system
  * Greatly improved textures and animations for the roman faction
  * New maps
  * Better network game performance / management to handle slower clients.
  * Easier ability to download game content from host and masterserver if available there.
  * New arranged options menu with several sub menus
  * Menu GUI improvements
  * Attack hotkey toggles through all attack types
  * Single player games can be sped up incrementally in steps.
  * Color picking is greatly improved and the default selection mode now for better compatibility
  * greater ability to translate game content (including techtrees) into your native language.
  * Added Hebrew, Arabic, Vietnamese (and others).
  * Screenshots for savegames without annoying menu in screenshot.
  * Addition of google-breakpad to better track down bugs.
  * Many new lua functions for scenario modders.
  * Cell coordinates are shown in the mapeditor.
  * Tilesets can set default air unit heights
  * Added ability for stand alone mod's to customize more of the engine like about screen.
  * Improved textures for tech faction
  * Performance improvements
  * and as always many bugs were fixed
* Mon Sep  2 2013 joop.boonen@opensuse.org
- Update to version 3.8.0-beta1
* Thu Jun  6 2013 joop.boonen@opensuse.org
- Created a miniupnpc 1.8 patch
* Tue Nov 27 2012 joop.boonen@opensuse.org
- Build megaglest version 3.7.1
* Sat Nov 24 2012 joop.boonen@opensuse.org
- Removed not needed BuildRequires:  libGLw1
* Sun Nov 18 2012 joop.boonen@opensuse.org
- Build megaglest version 3.7.0
- Created font and lua patches
* Fri May 11 2012 joop.boonen@opensuse.org
- openSUSE package MesaGLw-devel has been renamed to libGLw-devel
* Mon Apr 30 2012 joop.boonen@opensuse.org
- gcc47 patch partly based on Fedora glest patch
  http://lists.fedoraproject.org/pipermail/scm-commits/2012-January/726167.html
* Wed Apr 25 2012 joop.boonen@opensuse.org
- Added lua => 5.2 patch luaL_getn isn't used anymore, is replaced by lua_rawlen
* Tue Mar 27 2012 joop.boonen@opensuse.org
- p7zip is needed by megalglest to install game content
* Sun Jan 29 2012 joop.boonen@opensuse.org
- Added borrowed _DATE_ and _TIME_ replace from
  openSUSE MozillaFirefox.spec file
* Sat Jan 28 2012 joop.boonen@opensuse.org
- Build megaglest version 3.6.0.3
- Got rid of Obsoletes glest
* Sat Jan  7 2012 joop.boonen@opensuse.org
- Using boost-jam in stead of jam
* Thu Jan  5 2012 joop.boonen@opensuse.org
- Created megaglest-fontpath.diff so
  megaglest-source-embedded-3.6.0.2.tar.xz doesn't need to be used
* Thu Jan  5 2012 joop.boonen@opensuse.org
- icons.tar.bz2 removed isn't needed
* Fri Dec 23 2011 jengelh@medozas.de
- Remove redundant/unwanted tags/section (cf. specfile guidelines)
- Use %%_smp_mflags for parallel building
* Fri Dec 23 2011 joop.boonen@opensuse.org
- Build version 3.6.0.2
* Fri Sep 23 2011 joop.boonen@opensuse.org
- Build version 3.5.2.4
* Mon May 30 2011 joop.boonen@opensuse.org
- corrected README.SUSE
* Sat May 14 2011 joop.boonen@opensuse.org
- build version 3.5.2
- the wrapper script is not needed anymore
* Sat May 14 2011 joop.boonen@opensuse.org
- build version 3.5.1
- adapted the wrapper script
* Mon Apr 25 2011 joop.boonen@opensuse.org
- build version 3.5.0
* Sun Mar  6 2011 joop.boonen@opensuse.org
- corrected provide and requires
- subversion is also needed
- correction desktop file
* Tue Mar  1 2011 prusnak@opensuse.org
- spec cleanup
- don't strip binaries
- provide and obsolete glest
- fix wxWidgets usage for 11.4+
* Fri Feb  4 2011 nick.schrader@iserv-gis.de
- build megaglest 3.4.0
- changed package name to megaglest
* Mon Oct 18 2010 joop.boonen@opensuse.org
- build megaglest 3.3.7.2
* Sat Oct 16 2010 joop.boonen@opensuse.org
- build megaglest 3.3.7
  * Significant game play performance improvements.
  * Added support for FreeBSD (thanks m0ellemeister) and Mac OS X (thanks GeoVah)!
  * Players can now tell multiple units to build a new unit all at the same time (multi-build)
  * Particle and Transparency improvements
  * Map Preview in game lobby
  * Added ability to pick a random faction in the game lobby
  * Added ability to be a non-player and Observe a network game (becoming an Observer)
  * Added ability to change playername in game lobby
  * Added new map filter (to display maps with x players)
  * AI Player improvements
  * Added new LUA functions and events (see wiki for details).
  * Added numerous new commandline options (use --help to see a detailed list)
  * Improved network performance
  * Masterserver PHP scripts will now run on a Microsoft Windows Server
  * Added ability to move / size UI components in a custom manner
  * Many bugfixes.
* Sun Aug 29 2010 joop.boonen@opensuse.org
- build megaglest 3.3.6
  - megaglest is an extended glest version with the
    megapack included
  - needed to add the missing icons via icons.tar
- better cross distro support
* Wed Nov 25 2009 joop.boonen@opensuse.org
- corrected the file location in glest-help.desktop
* Wed Nov 25 2009 prusnak@suse.cz
- simplify glest wrapper a bit
* Wed Nov 25 2009 joop.boonen@opensuse.org
- added a rewrite of the glest.ini file to 3.2.2 syntax
* Tue Nov 24 2009 prusnak@suse.cz
- fix problems with loading .lng files [bnc#557747]
* Wed Nov 18 2009 joop.boonen@opensuse.org
- building version 3.2.2
- build with gentoo patch http://bugs.gentoo.org/259701
- build with mandriva patch
* Thu Mar  6 2008 sndirsch@suse.de
- removed conflicting map 'swamp_of_sorrow.gbm', which is now in
  glest-data package
- glest.sh: make sure FogOfWar* variables are added to glest.ini
  if glest is updated and they don't exist yet.
* Thu Mar  6 2008 sndirsch@suse.de
- updated to glest 3.1.2
* Thu Feb 21 2008 prusnak@suse.cz
- updated to glest 3.1.0
* Thu Jan 31 2008 sndirsch@suse.de
- updated to glest 3.0.0 final release
  * Network play over LAN/Internet
  * New key shortcuts for giving orders and selecting special units
  * Renamed some units
  * Reworked tech faction upgrades
  * Balance changes
* Wed Jan 16 2008 sndirsch@suse.de
- updated to glest 3.0.0 Beta1
* Sun Nov 18 2007 sndirsch@suse.de
- glest.sh: create symlink to scenarios directory
* Sun Nov 18 2007 sndirsch@suse.de
- glest.sh: convert configuration from glest 1.1 to glest 1.2
* Sat Nov 17 2007 sndirsch@suse.de
- updated to SVN 2007-10-17 (3.0.0-alpha1, which includes
  experimental multiplayer support for LAN/Internet)
* Mon Oct 15 2007 sndirsch@suse.de
- added 'german.lng' compatibilty symlink (Bug #333702)
* Wed Aug  8 2007 sndirsch@suse.de
- more maps
- more translations
* Fri Mar 30 2007 ro@suse.de
- added unzip to buildreq
* Thu Dec 28 2006 sndirsch@suse.de
- use new jam package for building
* Sun Sep  3 2006 sndirsch@suse.de
- fixed version number in specfile
* Fri Jun 16 2006 sndirsch@suse.de
- fixed build on SUSE < 10.0
* Mon May 15 2006 sndirsch@suse.de
- back to CVS sources
  * obsoletes gcc41.diff
* Sat Apr 15 2006 sndirsch@suse.de
- updated to 2.0.0 sources in zip format
  * New Magic units:
  * Tower of Souls: Air defense building, attacks air only
  * Golem: Defensive unit, needs EP to walk, can't attack air
  * Daemon giant: Heavy melee unit
  * Drake rider: Light ranged unit
  * New Tech units:
  * Aerodrome: Building for producing air units
  * Air ballista: Air defense building, attacks air only
  * Rider: Fast medium unit
  * Ornithopter: Light air unit
  * Airship: Heavy air unit, can't attack air
  * New Magic upgrades
  * New Tech upgrades
  * New animations for existing units
  * Shared vision between allies
  * New particle blending
  * Felix and Matze added to the credits
  * Players now start on the location indicated in the game settings menu
  * Score system
  * HTML documentation
  * Increased projectile accuracy
  * Optimized particle rendering
  * Loads of balance changes
- disabled savegame patch for now
* Fri Mar 17 2006 sndirsch@suse.de
- make "Center_Punch" the default map; it's simply much more
  spectacular than "Amazone" (action from the beginning)
* Thu Mar 16 2006 sndirsch@suse.de
- remove stale sysmlink to no longer existing screens directory
- update ATI information in info file used by xmessage
* Fri Jan 27 2006 nadvornik@suse.cz
- fixed BuildRequires
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Sat Nov 12 2005 sndirsch@suse.de
- updated to 2.0rc2
- adjusted patches
* Mon Oct 24 2005 sndirsch@suse.de
- updated to glest 1.2.1
- adjusted DRI patch
- adjusted savegame patch
* Tue Oct 18 2005 sndirsch@suse.de
- removed extra qualifications (fatal error for gcc 4.1)
* Sun Oct  9 2005 sndirsch@suse.de
- updated french translation
- added catala translation
* Sun Oct  9 2005 sndirsch@suse.de
- added savegame patch (bkaindl) (#115199)
* Sat Oct  8 2005 sndirsch@suse.de
- updated to current glest CVS (2005-10-08) (#115199)
* Mon Sep  5 2005 sndirsch@suse.de
- glest-help.desktop:
  * fixed path of readme.txt
* Mon Sep  5 2005 sndirsch@suse.de
- added support for DRI drivers
  * neededforbuild: nvidiagl --> mesa-devel-packages
  * glest-1.1.0-linux-DRI.diff (bkaindl)
  * glest.sh: error message --> warning (which can be ignored)
* Tue Jul 12 2005 sndirsch@suse.de
- updated magyar translation
- added dutch + polish translations
- moved glest_data_v1.1.0.zip to new noarch glest-data package
* Tue Jul 12 2005 sndirsch@suse.de
- build only on %%ix86/x86_64
* Mon Jul 11 2005 sndirsch@suse.de
- norootforbuild
* Sun Jul 10 2005 sndirsch@suse.de
- updated to release 1.1.0
* Mon Jun 27 2005 sndirsch@suse.de
- fixed build on 9.2
* Mon Jun 27 2005 sndirsch@suse.de
- glest-1.0.10-r7-source.diff:
  * fixes OpenGL version check
* Tue May 17 2005 sndirsch@suse.de
- added "The lake" map
* Thu May 12 2005 sndirsch@suse.de
- use norootforbuild
* Sun Apr  3 2005 sndirsch@suse.de
- glest.sh:
  * abort if no ATI/NVIDIA driver is in use; use xmessage for this
* Sat Apr  2 2005 sndirsch@suse.de
- added Amazone map
* Fri Apr  1 2005 sndirsch@suse.de
- updated to version 1.0.10-r7
  * Changing an assert in the font code to a warning (this should
    help some people with asserts in font code). Updated README
    with warnings that SuSE 9.2 ships a broken OpenAL.
  * Fixes a messed up opengl check, fixes a crash in my last random
    number generator fix and merged kozz/dholms endianess patches
- added README for the glest engine to docs
* Fri Apr  1 2005 sndirsch@suse.de
- added license and readme to /usr/share/doc/packages/glest
- added README.SuSE for detailed configuration
* Tue Mar 29 2005 sndirsch@suse.de
- translations:
  * updated danish/magyar
  * added turkish
- added maps "Up-Hill-War" and "Center_Punch"
* Mon Mar 28 2005 sndirsch@suse.de
- glest.sh: preselect correct language when possible
* Sat Mar 26 2005 sndirsch@suse.de
- added destkop files including icons
* Sat Mar 26 2005 sndirsch@suse.de
- added translations for dansk, german, euskara, francais,
  italiano, magyar, norsk, portugues
* Sat Mar 26 2005 sndirsch@suse.de
- created package
